@@ -147,7 +147,7 @@ insert_tag (const GstTagList *list, const gchar *tag, DAAPRecord *record)
 			g_object_set (record, "songartist", val, NULL);
 		} else if (! strcmp ("album", tag)) {
 			g_object_set (record, "songalbum", val, NULL);
-		} else if (! strcmp ("disc-number", tag)) {
+		} else if (! strcmp ("album-disc-number", tag)) {
 			errno = 0;
 			long disc = strtol (val, NULL, 10);
 			if (! errno) {
