@@ -130,6 +130,21 @@ cache_read (const gchar *path)
         return blob;
 }
 
+static guint
+dmapd_dmap_db_ghashtable_add_with_id (DMAPDb *db, DMAPRecord *record, guint id)
+{
+	g_hash_table_insert (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db, GUINT_TO_POINTER (id), record);
+	return id;
+}
+
+static guint
+dmapd_dmap_db_ghashtable_add_no_cache (DMAPDb *db, DMAPRecord *record)
+{
+	g_object_ref (record);
+
+	return dmapd_dmap_db_ghashtable_add_with_id (db, record, nextid--);
+}
+
 static void
 load_cached_records (DMAPDb *db, const gchar *db_dir, DMAPRecordFactory *factory)
 {
@@ -154,7 +169,7 @@ load_cached_records (DMAPDb *db, const gchar *db_dir, DMAPRecordFactory *factory
 						DMAPRecord *record = dmap_record_factory_create (factory, NULL);
 						if (NULL != record) {
 							if (dmap_record_set_from_blob (record, blob)) {
-								dmap_db_add (DMAP_DB (db), record);
+								dmapd_dmap_db_ghashtable_add_no_cache (DMAP_DB (db), record);
 							} else {
 								g_warning ("Removing stale cache entry %s\n", path);
 								g_unlink (path);
@@ -172,13 +187,6 @@ load_cached_records (DMAPDb *db, const gchar *db_dir, DMAPRecordFactory *factory
 	}
 }
 
-static guint
-dmapd_dmap_db_ghashtable_add_with_id (DMAPDb *db, DMAPRecord *record, guint id)
-{
-	g_hash_table_insert (DMAPD_DMAP_DB_GHASHTABLE (db)->priv->db, GUINT_TO_POINTER (id), record);
-	return id;
-}
-
 static guint
 dmapd_dmap_db_ghashtable_add (DMAPDb *db, DMAPRecord *record)
 {
@@ -186,8 +194,6 @@ dmapd_dmap_db_ghashtable_add (DMAPDb *db, DMAPRecord *record)
 	GByteArray *blob = NULL;
 	gchar *location  = NULL;;
 
-	g_object_ref (record);
-
 	g_object_get (record, "location", &location, NULL);
 	g_object_get (db, "db-dir", &db_dir, NULL);
 
@@ -208,7 +214,7 @@ dmapd_dmap_db_ghashtable_add (DMAPDb *db, DMAPRecord *record)
 		g_byte_array_unref (blob);
 	}
 
-	return dmapd_dmap_db_ghashtable_add_with_id (db, record, nextid--);
+	return dmapd_dmap_db_ghashtable_add_no_cache (db, record);
 }
 
 static guint
